@@ -4,6 +4,7 @@ import shutil
 import sys
 import os
 import json
+import cchardet
 from typing import List, Optional, Tuple, Union
 from log2json.status import ExitStatus
 from log2json.cli.definition import parser
@@ -107,7 +108,7 @@ def program(args: argparse.Namespace) -> ExitStatus:
 					)
 				)
 
-			write2json(input_path, output_path)
+			write2json(input_path, output_path, args.e)
 		else:
 			if (args.d):
 				output_dir = os.path.abspath(args.d)
@@ -129,17 +130,30 @@ def program(args: argparse.Namespace) -> ExitStatus:
 					os.path.splitext(os.path.basename(input_path))[0] + '.json'
 				)
 
-				write2json(input_path, output_path)
+				write2json(input_path, output_path, args.e)
 
 	return exit_status
 
-def write2json(input_path: str, output_path: str):
+def write2json(input_path: str, output_path: str, regex: str):
+	if (regex):
+		import re
+		try:
+			re.compile(regex)
+		except re.error:
+			parser.error("Provided regex is not valid.")
+
 	o_fp = open(output_path, mode="w", encoding="utf-8")
 
 	lines = []
-	with open(input_path, mode="r") as i_fp:
+	encoding = cchardet.detect(open(input_path, mode="rb").read())['encoding']
+	with open(input_path, mode="r", encoding=encoding) as i_fp:
 		for line in i_fp:
-			lines.append(line.strip())
+			if (regex):
+				r = re.compile(regex)
+				x = [m.groupdict() for m in r.finditer(line.strip())]
+				lines.append(x[0])
+			else:
+				lines.append(line.strip())
 
 	json.dump(lines, fp=o_fp, indent=2)
 
